Advent of Code helpers
======================
.. image:: https://travis-ci.org/mvaal/advent-of-code-helpers.svg?branch=master
    :target: https://travis-ci.org/mvaal/advent-of-code-helpers


Advent of Code helper functions